//+------------------------------------------------------------------+
//|                                                      pokusaj.mq4 |
//|                        Copyright 2021, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2021, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"
#property strict

enum maTypes
  {
   ma_sma,     // simple moving average - SMA
   ma_ema,     // exponential moving average - EMA
   ma_dsema,   // double smoothed exponential moving average - DSEMA
   ma_dema,    // double exponential moving average - DEMA
   ma_tema,    // tripple exponential moving average - TEMA
   ma_smma,    // smoothed moving average - SMMA
   ma_lwma,    // linear weighted moving average - LWMA
   ma_pwma,    // parabolic weighted moving average - PWMA
   ma_alxma,   // Alexander moving average - ALXMA
   ma_vwma,    // volume weighted moving average - VWMA
   ma_hull,    // Hull moving average
   ma_tma,     // triangular moving average
   ma_sine,    // sine weighted moving average
   ma_linr,    // linear regression value
   ma_ie2,     // IE/2
   ma_nlma,    // non lag moving average
   ma_zlma,    // zero lag moving average
   ma_lead,    // leader exponential moving average
   ma_ssm,     // super smoother
   ma_smoo     // smoother
  };

// the input variables of the Kaufman
input ENUM_TIMEFRAMES    TimeFrame       = PERIOD_CURRENT;
input int                AMAPeriod       = 10;
input ENUM_APPLIED_PRICE AMAPrice        = PRICE_CLOSE;
input int                Nfast           = 2;
input int                Nslow           = 30;
input double             GCoeff          = 2;
input int                PriceFilter     = 5;
input maTypes            PriceFilterMode = ma_smoo;
input bool               Interpolate     = true;

// the input vriables of primary

//input int                r                     = 2;                 // First ema period
//input int                s                     = 10;                // Second ema period
//input int                u                     = 5;                 // Third ema period
//input int                trigger               = 3;                 // Signal ema period
//input ENUM_APPLIED_PRICE Price                 = PRICE_CLOSE;       // Price to use
//input bool               arrowsVisible         = false;             // Arrows visible true/false?
//input bool               arrowsOnNewest        = false;             // Arrows drawn on newest bar of higher time frame bar true/false?
//input string             arrowsIdentifier      = "erg Arrows1";     // Unique ID for arrows
//input double             arrowsUpperGap        = 0.1;               // Upper arrow gap
//input double             arrowsLowerGap        = 0.1;               // Lower arrow gap
//input color              arrowsUpColor         = clrBlue;           // Up arrow color
//input color              arrowsDnColor         = clrCrimson;        // Down arrow color
//input int                arrowsUpCode          = 116;               // Up arrow code
//input int                arrowsDnCode          = 116;               // Down arrow code
//input int                arrowsUpSize          = 2;                 // Up arrow size
//input int                arrowsDnSize          = 2;                 // Down arrow size              // Interpolate true/false?

//absoulte strength histogram
input int    Length =  3; // Period
input int    Smooth =  3; // Period of smoothing
input int    Signal =  3; // Period of Signal Line
input ENUM_MA_METHOD ModeMA = MODE_EMA; // Mode of Moving Average
input int    SuperSignalsPeriod = 96;   

input bool   ShowAlertLines   = true;
input int    BarsToCountLines = 500;
input color  LineUpColor      = clrBlue;
input color  LineDnColor      = clrRed;
input ENUM_LINE_STYLE LinesStyle = STYLE_DASH;
input int    LinesWidth       = 1;
input string SignalName       ="ASH line";
input string AlertSound       ="alert2";
input bool   AlertsOn         = true;
input bool   AlertsMesage     = true;
input bool   AlertsSound      = false;
input bool   AlertsEmail      = false;

//Waddah attar

extern int  Sensetive = 90;
extern double  DeadZonePip = 1.5;
extern int  ExplosionPower = 15;
extern int  TrendPower = 15;
extern int  BBandPeriod = 20;
extern double  BBandSD = 2.5;
extern int  FEMA = 12;
extern int  SEMA = 26;
extern int  SignalMA = 9;
extern int  AtrPeriod = 14;
extern ENUM_APPLIED_PRICE WaePrice = PRICE_MEDIAN;
extern bool AlertWindow = false;
extern int  AlertCount = 500;
extern bool AlertLong = false;
extern bool AlertShort = false;
extern bool AlertExitLong = false;
extern bool AlertExitShort = false;

//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
//---
   
//---
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---

  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//---
   //kaufman
   double band_middle = iCustom(_Symbol,_Period,"kaufman_ama_averages_filtered_ATR bands",TimeFrame, AMAPeriod, AMAPrice,Nfast, Nslow, GCoeff, PriceFilter, PriceFilterMode,Interpolate, 0,0 );
   double band_up = iCustom(_Symbol,_Period,"kaufman_ama_averages_filtered_ATR bands",TimeFrame, AMAPeriod, AMAPrice,Nfast, Nslow, GCoeff, PriceFilter,PriceFilterMode, Interpolate, 4,0 );
   double band_down = iCustom(_Symbol,_Period,"kaufman_ama_averages_filtered_ATR bands",TimeFrame, AMAPeriod, AMAPrice,Nfast, Nslow, GCoeff, PriceFilter,PriceFilterMode, Interpolate, 5,0 );
   
   //bh ergodic
   //double primary_green_line = iCustom(_Symbol, _Period, "bhergodic",TimeFrame, r, s ,u, trigger, Price,arrowsVisible, arrowsOnNewest, arrowsIdentifier, arrowsUpperGap, arrowsLowerGap, arrowsUpColor, arrowsDnColor,arrowsUpCode, arrowsDnCode, arrowsUpSize, arrowsDnSize, Interpolate, 0,0);
  // double primary_red_line = iCustom(_Symbol, _Period, "bhergodic",TimeFrame, r, s ,u, trigger, Price,arrowsVisible, arrowsOnNewest, arrowsIdentifier, arrowsUpperGap, arrowsLowerGap, arrowsUpColor, arrowsDnColor,arrowsUpCode, arrowsDnCode, arrowsUpSize, arrowsDnSize, Interpolate, 1,0);
   
   
   //ash
   double ash_bulls = iCustom(_Symbol, _Period, "ASH Secondary",Length, Smooth, Signal,ModeMA, SuperSignalsPeriod, ShowAlertLines, BarsToCountLines, LineUpColor, LineDnColor, LinesStyle, LinesWidth, SignalName, AlertSound, AlertsOn, AlertsMesage, AlertsSound, AlertsEmail, 0, 0);
   double ash_bears = iCustom(_Symbol, _Period, "ASH Secondary",Length, Smooth, Signal,ModeMA, SuperSignalsPeriod, ShowAlertLines, BarsToCountLines, LineUpColor, LineDnColor, LinesStyle, LinesWidth, SignalName, AlertSound, AlertsOn, AlertsMesage, AlertsSound, AlertsEmail, 1 ,0);
   Comment(ash_bulls);
   
   //waddah attar
   
   double waddah_long = iCustom(_Symbol, _Period, "WAE_Ext", Sensetive, DeadZonePip, ExplosionPower, TrendPower, BBandPeriod, BBandSD, FEMA, SEMA, SignalMA, AtrPeriod, WaePrice, AlertWindow, AlertCount , AlertLong, AlertShort, AlertExitLong, AlertExitShort, 0, 0);
   double waddah_short = iCustom(_Symbol, _Period, "WAE_Ext", Sensetive, DeadZonePip, ExplosionPower, TrendPower, BBandPeriod, BBandSD, FEMA, SEMA, SignalMA, AtrPeriod, WaePrice, AlertWindow, AlertCount , AlertLong, AlertShort, AlertExitLong, AlertExitShort, 1, 0);
   double waddah_explosion = iCustom(_Symbol, _Period, "WAE_Ext", Sensetive, DeadZonePip, ExplosionPower, TrendPower, BBandPeriod, BBandSD, FEMA, SEMA, SignalMA, AtrPeriod, WaePrice, AlertWindow, AlertCount , AlertLong, AlertShort, AlertExitLong, AlertExitShort, 2, 0);
   double waddah_death = iCustom(_Symbol, _Period, "WAE_Ext", Sensetive, DeadZonePip, ExplosionPower, TrendPower, BBandPeriod, BBandSD, FEMA, SEMA, SignalMA, AtrPeriod, WaePrice, AlertWindow, AlertCount , AlertLong, AlertShort, AlertExitLong, AlertExitShort, 3, 0);
   
   //strategy
   double band_middle_curr = iCustom(_Symbol,_Period,"kaufman_ama_averages_filtered_ATR bands",TimeFrame, AMAPeriod, AMAPrice,Nfast, Nslow, GCoeff, PriceFilter, PriceFilterMode,Interpolate, 0,0 );
   double band_middle_prev = iCustom(_Symbol,_Period,"kaufman_ama_averages_filtered_ATR bands",TimeFrame, AMAPeriod, AMAPrice,Nfast, Nslow, GCoeff, PriceFilter, PriceFilterMode,Interpolate, 0,1 );
   double band_up_prev = iCustom(_Symbol,_Period,"kaufman_ama_averages_filtered_ATR bands",TimeFrame, AMAPeriod, AMAPrice,Nfast, Nslow, GCoeff, PriceFilter,PriceFilterMode, Interpolate, 4,1 );
   double band_up_curr = iCustom(_Symbol,_Period,"kaufman_ama_averages_filtered_ATR bands",TimeFrame, AMAPeriod, AMAPrice,Nfast, Nslow, GCoeff, PriceFilter,PriceFilterMode, Interpolate, 4,0 );
   
   
  
   
   
   if((Close[0] >  band_middle && Close[0] < band_up) && (waddah_long > waddah_explosion) && (ash_bulls == 1.0))
      {
      
         Print("open a buy order");
      
      }
   
  }
//+------------------------------------------------------------------+
